Version History
===============


v2.0.1 - 2023 / 05 / 15
-----------------------

* Reduce Python version requirement to >3.6 instead of 3.7.
* Fix version number in Sphinx manual, which was retrieved from pymadx
  and not pytransport.
